@@ -18,8 +18,18 @@ async def post(path, data=None,
     if flag:
         if not kwargs.get("headers"):
             kwargs.update({"headers": {
-                "Content-Type": "application/json"
+                "Content-Type": "application/json",
+                "Application-Name": tornado.options.options.application_name
             }})
+        else:
+            kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
+    else:
+        if not kwargs.get("headers"):
+            kwargs.update({"headers": {
+                "Application-Name": tornado.options.options.application_name
+            }})
+        else:
+            kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
     async with aiohttp.ClientSession() as session:
         flag = kwargs.pop("flag", True)
         if flag:
@@ -56,6 +66,13 @@ async def post(path, data=None,
 
 async def get(path, params=None, base_url=tornado.options.options.data_server, result_type="json", pack=False,
               **kwargs):
+    if not kwargs.get("headers"):
+        kwargs.update({"headers": {
+            "Application-Name": tornado.options.options.application_name
+        }})
+    else:
+        kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
+
     async with aiohttp.ClientSession() as session:
         async with session.get(base_url + path, params=params, **kwargs) as resp:
             if result_type == "json":
@@ -76,6 +93,12 @@ async def get(path, params=None, base_url=tornado.options.options.data_server, r
 def sync_get(path, params=None, base_url=None, result_type="json", pack=False, **kwargs):
     if not base_url:
         base_url = tornado.options.options.data_server
+    if not kwargs.get("headers"):
+        kwargs.update({"headers": {
+            "Application-Name": tornado.options.options.application_name
+        }})
+    else:
+        kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
     res = requests.get(base_url + path, params=params, **kwargs)
     if result_type == "json":
         res = res.json()
@@ -101,10 +124,19 @@ def sync_post(path, data=None,
     if flag:
         if not kwargs.get("headers"):
             kwargs.update({"headers": {
-                "Content-Type": "application/json"
+                "Content-Type": "application/json",
+                "Application-Name": tornado.options.options.application_name
             }})
+        else:
+            kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
         res = requests.post(base_url + path, json=data, **kwargs)
     else:
+        if not kwargs.get("headers"):
+            kwargs.update({"headers": {
+                "Application-Name": tornado.options.options.application_name
+            }})
+        else:
+            kwargs["headers"].update({"Application-Name": tornado.options.options.application_name})
         res = requests.post(base_url + path, data=data, **kwargs)
     if result_type == "json":
         res = res.json()
